isClassSupported method
Check if the current class is supported by the defaultTargetPlatform or a specific platform.
Implementation
bool isClassSupported({TargetPlatform? platform}) =>
params.isClassSupported(platform: platform);
Check if the current class is supported by the defaultTargetPlatform or a specific platform.
bool isClassSupported({TargetPlatform? platform}) =>
params.isClassSupported(platform: platform);