PlatformHttpAuthCredentialDatabase class abstract

Class that implements a singleton object (shared instance) which manages the shared HTTP auth credentials cache.

Inheritance
  • Object
  • PlatformInterface
  • PlatformHttpAuthCredentialDatabase
Annotations
  • @SupportedPlatforms.new(platforms: [AndroidPlatform(note: 'It has a custom implementation using `android.database.sqlite.SQLiteDatabase` because [WebViewDatabase](https://developer.android.com/reference/android/webkit/WebViewDatabase) doesn\'t offer the same functionalities as iOS/macOS `URLCredentialStorage`.'), IOSPlatform(note: 'It is implemented using the [URLCredentialStorage](https://developer.apple.com/documentation/foundation/urlcredentialstorage) class.'), MacOSPlatform(note: 'It is implemented using the [URLCredentialStorage](https://developer.apple.com/documentation/foundation/urlcredentialstorage) class.'), LinuxPlatform(note: 'Implemented using libsecret for secure credential storage in the system keyring (gnome-keyring, KDE Wallet, etc.).')])

Properties

hashCode → int
The hash code for this object.
no setterinherited
params → PlatformHttpAuthCredentialDatabaseCreationParams
The parameters used to initialize the PlatformHttpAuthCredentialDatabase.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAllAuthCredentials() → Future<void>
Removes all the HTTP auth credentials saved in the database.
getAllAuthCredentials() → Future<List<URLProtectionSpaceHttpAuthCredentials>>
Gets a map list of all HTTP auth credentials saved. Each map contains the key protectionSpace of type URLProtectionSpace and the key credentials of type List<URLCredential> that contains all the HTTP auth credentials saved for that protectionSpace.
getHttpAuthCredentials({required URLProtectionSpace protectionSpace}) → Future<List<URLCredential>>
Gets all the HTTP auth credentials saved for that protectionSpace.
isClassSupported({TargetPlatform? platform}) → bool
Check if the current class is supported by the defaultTargetPlatform or a specific platform.
isMethodSupported(PlatformHttpAuthCredentialDatabaseMethod method, {TargetPlatform? platform}) → bool
Check if the given method is supported by the defaultTargetPlatform or a specific platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeHttpAuthCredential({required URLProtectionSpace protectionSpace, required URLCredential credential}) → Future<void>
Removes an HTTP auth credential for that protectionSpace.
removeHttpAuthCredentials({required URLProtectionSpace protectionSpace}) → Future<void>
Removes all the HTTP auth credentials saved for that protectionSpace.
setHttpAuthCredential({required URLProtectionSpace protectionSpace, required URLCredential credential}) → Future<void>
Saves an HTTP auth credential for that protectionSpace.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited